#!/usr/bin/env python
from apex.main import main

if __name__ == '__main__':
    main()
